"""Setup script."""


# [ Imports ]
from setuptools import setup, find_packages


# [ Setup ]
setup(
    name='a_sync',
    version='0.2.0',
    description='async helper library.',
    url='https://github.com/notion/a_sync',
    author='toejough',
    author_email='toejough@gmail.com',
    license='Apache 2.0',
    packages=find_packages(),
    install_requires=[],
)
